@@ -67,7 +67,7 @@ import configparser
 from subprocess import getoutput
 
 # NOTE: keep in sync with MDAnalysis.__version__ in version.py
-RELEASE = "2.3.0"
+RELEASE = "2.4.1"
 
 is_release = 'dev' not in RELEASE
 
@@ -266,6 +266,7 @@ def extensions(config):
     # usually (except coming from release tarball) cython files must be generated
     use_cython = config.get('use_cython', default=cython_found)
     use_openmp = config.get('use_openmp', default=True)
+    annotate_cython = config.get('annotate_cython', default=False)
 
     extra_compile_args = ['-std=c99', '-ffast-math', '-O3', '-funroll-loops',
                           '-fsigned-zeros'] # see #2722
@@ -449,6 +450,7 @@ def extensions(config):
     if use_cython:
         extensions = cythonize(
             pre_exts,
+            annotate=annotate_cython,
             compiler_directives={'linetrace': cython_linetrace,
                                  'embedsignature': False,
                                  'language_level': '3'},
@@ -571,7 +573,7 @@ if __name__ == '__main__':
         'Development Status :: 6 - Mature',
         'Environment :: Console',
         'Intended Audience :: Science/Research',
-        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
+        'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)',
         'Operating System :: POSIX',
         'Operating System :: MacOS :: MacOS X',
         'Operating System :: Microsoft :: Windows ',
@@ -580,6 +582,7 @@ if __name__ == '__main__':
         'Programming Language :: Python :: 3.8',
         'Programming Language :: Python :: 3.9',
         'Programming Language :: Python :: 3.10',
+        'Programming Language :: Python :: 3.11',
         'Programming Language :: C',
         'Topic :: Scientific/Engineering',
         'Topic :: Scientific/Engineering :: Bio-Informatics',
@@ -591,7 +594,7 @@ if __name__ == '__main__':
 
     install_requires = [
           'numpy>=1.20.0',
-          'biopython>=1.71',
+          'biopython>=1.80',
           'networkx>=2.0',
           'GridDataFormats>=0.4.0',
           'mmtf-python>=1.0.0',
@@ -607,8 +610,7 @@ if __name__ == '__main__':
 
     setup(name='MDAnalysis',
           version=RELEASE,
-          description=('An object-oriented toolkit to analyze molecular dynamics '
-                       'trajectories generated by CHARMM, Gromacs, NAMD, LAMMPS, or Amber.'),
+          description='An object-oriented toolkit to analyze molecular dynamics trajectories.',
           long_description=LONG_DESCRIPTION,
           long_description_content_type='text/x-rst',
           author='MDAnalysis Development Team',
@@ -626,7 +628,7 @@ if __name__ == '__main__':
                         'Twitter': 'https://twitter.com/mdanalysis',
                         'Source': 'https://github.com/mdanalysis/mdanalysis',
                         },
-          license='GPL 2',
+          license='GPL-2.0-or-later',
           classifiers=CLASSIFIERS,
           provides=['MDAnalysis'],
           packages=find_packages(),
@@ -647,13 +649,12 @@ if __name__ == '__main__':
           # you might prefer to use the version available through your
           # packaging system
           extras_require={
-              'AMBER': [           # REMOVE for 2.4.0, use 'extra_formats'
-                  'netCDF4>=1.0',  # for fast AMBER writing, also needs HDF5
-              ],
               'extra_formats': [   # additional file formats
                   'netCDF4>=1.0',  # for fast AMBER writing, also needs HDF5
                   'h5py>=2.10',    # H5MD
+                  'pytng>=0.2.3',  # TNG
                   'chemfiles>=0.10',  # multiple formats supported by chemfiles
+                  'pyedr>=0.7.0',  # EDR files for the EDR AuxReader
                   ],
               'analysis': [
                   'seaborn',  # for annotated heat map and nearest neighbor
