@@ -87,7 +87,7 @@ if sys.version_info[:2] < (3, 8):
 
 if __name__ == '__main__':
     # this must be in-sync with MDAnalysis
-    RELEASE = "2.3.0"
+    RELEASE = "2.4.1"
     with open("README") as summary:
         LONG_DESCRIPTION = summary.read()
 
@@ -95,7 +95,7 @@ if __name__ == '__main__':
         'Development Status :: 6 - Mature',
         'Environment :: Console',
         'Intended Audience :: Science/Research',
-        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
+        'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)',
         'Operating System :: POSIX',
         'Operating System :: MacOS :: MacOS X',
         'Operating System :: Microsoft :: Windows ',
@@ -104,6 +104,7 @@ if __name__ == '__main__':
         'Programming Language :: Python :: 3.8',
         'Programming Language :: Python :: 3.9',
         'Programming Language :: Python :: 3.10',
+        'Programming Language :: Python :: 3.11',
         'Programming Language :: C',
         'Topic :: Scientific/Engineering',
         'Topic :: Scientific/Engineering :: Bio-Informatics',
@@ -128,7 +129,7 @@ if __name__ == '__main__':
                         'Issue Tracker': 'https://github.com/mdanalysis/mdanalysis/issues',
                         'Source': 'https://github.com/mdanalysis/mdanalysis',
                         },
-          license='GPL 2',
+          license='GPL-2.0-or-later',
           classifiers=CLASSIFIERS,
           packages=find_packages(),
           package_dir={'MDAnalysisTests': 'MDAnalysisTests',
@@ -178,6 +179,10 @@ if __name__ == '__main__':
                          'data/*.in',
                          'data/*.top',
                          'data/*.sdf',
+                         'data/*.edr',
+                         'data/*.tng',
+                         'data/*.pdbx',
+                         'data/*.txt',
                         ],
           },
           python_requires='>=3.8',
